@@ -1,4 +1,3 @@
-require 'ms_rest_azure'
 require 'azure/core/http/http_error'
 require 'erb'
 require 'fog/azurerm/config'
@@ -12,11 +11,6 @@ require 'fog/azurerm/models/storage/sku_tier'
 require 'fog/azurerm/models/storage/kind'
 
 module Fog
-  # Autoload Module for Credentials
-  module Credentials
-    autoload :AzureRM, File.expand_path('azurerm/credentials', __dir__)
-  end
-
   # Autoload Module for Storage
   module Storage
     autoload :AzureRM, File.expand_path('azurerm/storage', __dir__)
