@@ -2,13 +2,6 @@ module Fog
   module Storage
     # This class registers models, requests and collections
     class AzureRM < Fog::Service
-      # Recognizes when creating management client
-      recognizes :tenant_id
-      recognizes :client_id
-      recognizes :client_secret
-      recognizes :subscription_id
-      recognizes :environment
-
       # Recognizes when creating data client
       recognizes :azure_storage_account_name
       recognizes :azure_storage_access_key
@@ -95,17 +88,6 @@ module Fog
             raise e.message
           end
 
-          options[:environment] = 'AzureCloud' if options[:environment].nil?
-
-          @tenant_id = options[:tenant_id]
-          @client_id = options[:client_id]
-          @client_secret = options[:client_secret]
-          @subscription_id = options[:subscription_id]
-          @environment = options[:environment]
-
-          credentials = Fog::Credentials::AzureRM.get_credentials(@tenant_id, @client_id, @client_secret, @environment)
-          telemetry = "gitlab-fog-azure-rm/#{Fog::AzureRM::VERSION}"
-
           return unless @azure_storage_account_name != options[:azure_storage_account_name] ||
                         @azure_storage_access_key != options[:azure_storage_access_key]
 
